=======================
Searchlight Policy File
=======================

Enable Searchlight policy::

    $ cp searchlight_ui/conf/searchlight_policy.json openstack-dashboard/openstack_dashboard/conf
